%define anolis_release 4
%global _smp_build_ncpus 1

Name:           libssh
Version:        0.10.5
Release:        %{anolis_release}%{?dist}
Summary:        A library implementing the SSH protocol
License:        LGPLv2+
URL:            http://www.libssh.org
Source0:        https://www.libssh.org/files/0.10/%{name}-%{version}.tar.xz
Source3:        libssh_server.config
Source4:        libssh_client.config

# FIX CVE-2023-6004 / CVE-2023-48795 / CVE-2023-6918
# https://git.libssh.org/projects/libssh.git/commit/?id=57ec9a35c612d416bfc045c48ccb69a5e9b57008 
# to
# https://git.libssh.org/projects/libssh.git/commit/?id=6f6e453d7b0ad4ee6a6f6a1c96a9a6b27821410d
# except https://git.libssh.org/projects/libssh.git/commit/?id=10e09e273f69e149389b3e0e5d44b8c221c2e7f6
Patch0001:      0001-CVE-2023-6004-config_parser-Allow-multiple-in-userna.patch
Patch0002:      0002-CVE-2023-6004-options-Simplify-the-hostname-parsing-.patch
Patch0003:      0003-CVE-2023-6004-misc-Add-function-to-check-allowed-cha.patch
Patch0004:      0004-CVE-2023-6004-torture_misc-Add-test-for-ssh_check_ho.patch
Patch0005:      0005-CVE-2023-6004-config_parser-Check-for-valid-syntax-o.patch
Patch0006:      0006-CVE-2023-6004-torture_proxycommand-Add-test-for-prox.patch
Patch0007:      0007-CVE-2023-6004-torture_misc-Add-test-for-ssh_is_ipadd.patch
Patch0008:      0008-CVE-2023-6004-misc-Add-ipv6-link-local-check-for-an-.patch
Patch0009:      0009-CVE-2023-6004-torture_misc-Add-tests-for-ipv6-link-l.patch
Patch0010:      0010-CVE-2023-48795-client-side-mitigation.patch
Patch0011:      0011-CVE-2023-48795-Server-side-mitigations.patch
Patch0012:      0012-CVE-2023-48795-Strip-extensions-from-both-kex-lists-.patch
Patch0013:      0013-CVE-2023-48795-tests-Adjust-calculation-to-strict-ke.patch
Patch0014:      0014-CVE-2023-6918-kdf-Reformat.patch
Patch0015:      0015-CVE-2023-6918-Remove-unused-evp-functions-and-types.patch
Patch0016:      0016-CVE-2023-6918-Systematically-check-return-values-whe.patch
Patch0017:      0017-CVE-2023-6918-kdf-Detect-context-init-failures.patch
Patch0018:      0018-CVE-2023-6918-tests-Code-coverage-for-ssh_get_pubkey.patch
Patch0019:      0019-CVE-2023-6004-torture_config-Allow-multiple-in-usern.patch
Patch0020:      0020-Fix-regression-in-IPv6-addresses-in-hostname-parsing.patch
Patch0021:      0021-tests-Increase-test-coverage-for-IPv6-address-parsin.patch

BuildRequires:  cmake gcc-c++
BuildRequires:  openssl-devel zlib-devel krb5-devel libcmocka-devel
BuildRequires:  pam_wrapper socket_wrapper nss_wrapper uid_wrapper
BuildRequires:  openssh-clients openssh-server openssl-pkcs11
BuildRequires:  gnutls-utils pkgconfig nmap-ncat softhsm

Requires:       %{name}-config = %{version}-%{release}

Recommends:     crypto-policies

Provides:       libssh_threads.so.4()(64bit)

%description
libssh is a C library that enables you to write a program that uses
the SSH protocol. With it, you can remotely execute programs, transfer
files, or use a secure and transparent tunnel for your remote programs.
The SSH protocol is encrypted, ensures data integrity, and provides
strong means of authenticating both the server of the client. The library
hides a lot of technical details from the SSH protocol, but this does not
mean that you should not try to know about and understand these details.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
This package provides libraries and header files for developers of
applications that use %{name}.

%package config
Summary:        Configuration files for %{name}
BuildArch:      noarch
Obsoletes:      %{name} < 0.9.0

%description config
The %{name}-config package provides the default configuration files for %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%cmake \
    -DUNIT_TESTING=ON \
    -DCLIENT_TESTING=ON \
    -DSERVER_TESTING=ON \
    -DGLOBAL_CLIENT_CONFIG="%{_sysconfdir}/libssh/libssh_client.config" \
    -DGLOBAL_BIND_CONFIG="%{_sysconfdir}/libssh/libssh_server.config"

%cmake_build

%install
%cmake_install
install -m 0755 -p -d %{buildroot}%{_sysconfdir}/libssh
install -m 0644 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/libssh/libssh_server.config
install -m 0644 -p %{SOURCE4} %{buildroot}%{_sysconfdir}/libssh/libssh_client.config


pushd %{buildroot}%{_libdir}
for i in libssh.so*;
do
    _target="${i}"
    _link_name="${i%libssh*}libssh_threads${i##*libssh}"
    if [ -L "${i}" ]; then
        _target="$(readlink ${i})"
    fi
    ln -s "${_target}" "${_link_name}"
done;
popd

%generate_compatibility_deps

%check
%ctest

%files
%dir %{abidir}
%license COPYING
%doc BSD
%{_libdir}/libssh.so.4*
%{_libdir}/libssh_threads.so.4*
%{abidir}/libssh*.dump

%files devel
%dir %{_libdir}/cmake/
%{_libdir}/cmake/libssh/libssh-config-noconfig.cmake
%{_libdir}/cmake/libssh/libssh-config-version.cmake
%{_libdir}/cmake/libssh/libssh-config.cmake
%{_libdir}/pkgconfig/libssh.pc
%{_libdir}/libssh.so
%{_libdir}/libssh_threads.so
%{_includedir}/libssh/

%files config
%attr(0755,root,root) %dir %{_sysconfdir}/libssh
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/libssh/libssh_client.config
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/libssh/libssh_server.config

%files doc
%doc AUTHORS CHANGELOG README

%changelog
* Tue Jun 10 2025 Weisson <Weisson@linux.alibaba.com> - 0.10.5-4
- Rebuild for cmake-3.30.5.

* Wed Mar 12 2025 Chang Gao <gc-taifu@linux.alibaba.com> - 0.10.5-3
- Fix CVE-2023-6004
- Fix CVE-2023-48795 
- Fix CVE-2023-6918

* Wed May 22 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.10.5-2
- fix source link

* Fri May 05 2023 Funda Wang <fundawang@yeah.net> - 0.10.5-1
- New version 0.10.5

* Mon Apr 10 2023 Guyu Wang <guyu.wgy@linux.alibaba.com> - 0.10.4-4
- optimise spec file

* Mon Feb 13 2023 Guyu Wang <guyu.wgy@linux.alibaba.com> - 0.10.4-3
- Enable pkcs11 support

* Thu Oct 20 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.10.4-2
- optimise spec file

* Mon Sep 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.10.4-1
- update to 0.10.4

* Fri Mar 04 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.9.6-2.1
- Init from upstream verison 0.9.6-2
